@@ -1,5 +1,3 @@
-#from django.core.paginator import Paginate
-
 try:
     import floppyforms as forms
 except ImportError:
@@ -31,6 +29,7 @@ class BaseMongoAdmin(object):
     formfield_overrides = {}
     readonly_fields = ()
     ordering = None
+
     
     def has_permission(self, request):
         """
@@ -58,6 +57,4 @@ class MongoAdmin(BaseMongoAdmin):
     list_editable = ()
     search_fields = ()
     save_as = False
-    save_on_top = False
-    #paginator = Paginator
-    inlines = []
\ No newline at end of file
+    save_on_top = False
\ No newline at end of file
